<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color</source>
        <translation>Clic para cambiar a cor</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Seleccione a cor</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="178"/>
        <source>GTK themes</source>
        <translation>Temas de GTK</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="179"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;«%1» foi sobrescrito.&lt;/p&gt;&lt;p&gt;Pode atopar unha copia da configuración antiga en «%2»&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error: gsettings cannot be run</source>
        <translation>Error: non se pode executar gsettings</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Tipo de letra</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Tipo de letra predeterminado para a interface</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Nome do tipo de letra:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Estilo:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="77"/>
        <source>Point size:</source>
        <translation>Tamaño en puntos:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="54"/>
        <source>Normal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="59"/>
        <source>Bold</source>
        <translation>Grosa</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="64"/>
        <source>Italic</source>
        <translation>Itálica</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="69"/>
        <source>Bold Italic</source>
        <translation>Itálica grosa</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Os seguintes axustes só afectan ás aplicacións iniciadas a partires de agora</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Usar o suavizado das letras</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="153"/>
        <source>Font hinting style:</source>
        <translation>Estilo do suavizado das letras:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="211"/>
        <source>Monospace:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="164"/>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="169"/>
        <source>Slight</source>
        <translation>Lene</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="174"/>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="179"/>
        <source>Full</source>
        <translation>Total</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="146"/>
        <source>Font hinting</source>
        <translation>Suavizado das letras</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="187"/>
        <source>Resolution (DPI):</source>
        <translation>Resolución (PPP):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="204"/>
        <source>Autohint</source>
        <translation>Suavizado automático</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Subpixel antialiasing:</source>
        <translation>Suavizado de subpixel:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>RGB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>BGR</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>VRGB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="138"/>
        <source>VBGR</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="56"/>
        <source>GTK Style</source>
        <translation>Estilo GTK</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="75"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Estabelecer os temas para GTK (sobrescribe os ficheiros de configuración de GTK)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="105"/>
        <source>GTK 3 Theme:</source>
        <translation>Tema para GTK 3:</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="89"/>
        <source>GTK 2 Theme:</source>
        <translation>Tema para GTK 2:</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="117"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Para tentar uniformar os temas, seleccione un estilo/tema similar (se está dispoñíbel) en todas as listas ou seleccione o estilo Qt «gtk2» (se está dispoñíbel) para imitar os temas GTK.

Asegúrese de que «xsettingsd» está instalado para axudar ás aplicacións GTK a aplicar temas ao voo.</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuración da aparencia do LXQt</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Tema de iconas</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>A extensión de KDE para temas de iconas XDG -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Colorar as iconas segundo o estilo dos trebellos (paleta)</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>Tema do LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation>Usar un fondo de pantalla fornecido polo tema</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="64"/>
        <source>Use palette provided by theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="83"/>
        <source>(User Theme)</source>
        <translation>(Tema do usuario)</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="188"/>
        <source>Open theme folder</source>
        <translation>Abrir o cartafol de temas</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>Paletas</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>Filtrar...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>&amp;Retirar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuración da aparencia do LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Widget Style</source>
        <translation>Estilo dos trebellos</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>Icons Theme</source>
        <translation>Tema de iconas</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>LXQt Theme</source>
        <translation>Tema do LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Font</source>
        <translation>Tipo de letra</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>Cursor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>GTK Style</source>
        <translation>Estilo GTK</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="45"/>
        <source>Widget Style</source>
        <translation>Estilo dos trebellos</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="75"/>
        <source>Qt Palette</source>
        <translation>Paleta de Qt</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="89"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Algúns estilos de Qt poden ignorar estas cores.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="114"/>
        <source>Window:</source>
        <translation>Xanela:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="124"/>
        <source>View:</source>
        <translation>Ver:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="134"/>
        <source>Selection:</source>
        <translation>Selección:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="144"/>
        <source>Tooltip:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="158"/>
        <source>Link:</source>
        <translation>Ligazón:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="178"/>
        <source>Window Text:</source>
        <translation>Texto da xanela:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="188"/>
        <source>View Text:</source>
        <translation>Ver texto:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="198"/>
        <source>Selected Text:</source>
        <translation>Texto seleccionado:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="208"/>
        <source>Tooltip Text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="222"/>
        <source>Visited Link:</source>
        <translation>Ligazón visitada:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="254"/>
        <source>&amp;Save Palette</source>
        <translation>&amp;Gardar paleta</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="261"/>
        <source>&amp;Load Palette</source>
        <translation>&amp;Cargar paleta</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="281"/>
        <source>&amp;Default Palette</source>
        <translation>&amp;Paleta predefinida</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="296"/>
        <location filename="../styleconfig.ui" line="306"/>
        <location filename="../styleconfig.ui" line="338"/>
        <location filename="../styleconfig.ui" line="348"/>
        <location filename="../styleconfig.ui" line="380"/>
        <source>May be overridden by Qt style or app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="299"/>
        <source>Toolbar button style:</source>
        <translation>Estilo dos botóns da barra de ferramentas:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="310"/>
        <source>Only display the icon</source>
        <translation>Amosar só a icona</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="315"/>
        <source>Only display the text</source>
        <translation>Amosar só o texto</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="320"/>
        <source>The text appears beside the icon</source>
        <translation>O texto aparece á beira da icona</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="325"/>
        <source>The text appears under the icon</source>
        <translation>O texto aparece baixo a icona</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="330"/>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="341"/>
        <source>Toolbar icon size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="352"/>
        <source>16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="357"/>
        <source>22</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="362"/>
        <source>24</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="367"/>
        <source>32</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="372"/>
        <source>48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="383"/>
        <source>Activate item on single click</source>
        <translation>Activar os elementos cun só clic</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Style:</source>
        <translation>Estilo de Qt:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <location filename="../styleconfig.cpp" line="340"/>
        <source>Save Palette</source>
        <translation>Cargar paleta</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <source>Palette name:</source>
        <translation>Nome da paleta:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="341"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>Existe unha paleta co mesmo nome.
Quere substituíla?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="484"/>
        <source>Remove Palettes</source>
        <translation>Eliminar paletas</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="485"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>Realmente desexa eliminar as paletas seleccionadas?
As paletas raíz permanecerán intactas se existiren.</translation>
    </message>
</context>
</TS>
